==> sal-signup-2.18.0-20170310.061946-52-sources.jar: com/baijia/tianxiao/sal/signup/service/Impl/TxStudentFinanceAccountServiceImpl.java <==
package com.baijia.tianxiao.sal.signup.service.Impl;

import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceAccountDto;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baijia.tianxiao.constant.StudentFiannceOpType;
import com.baijia.tianxiao.dal.finance.dao.TxStudentFinanceAccountDao;
import com.baijia.tianxiao.dal.finance.dao.TxStudentFinanceRecordDao;
import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceAccount;
import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceRecord;
import com.baijia.tianxiao.dal.org.dao.OrgInfoDao;
import com.baijia.tianxiao.dal.org.dao.OrgStudentDao;
import com.baijia.tianxiao.dal.org.dao.TXCascadeCredentialDao;
import com.baijia.tianxiao.dal.org.po.OrgInfo;
import com.baijia.tianxiao.dal.org.po.OrgStudent;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.exception.BussinessException;
import com.baijia.tianxiao.sal.organization.finance.constant.FinanceOpTo;
import com.baijia.tianxiao.sal.organization.org.service.TxCascadeCredentialService;
import com.baijia.tianxiao.sal.signup.dto.BalanceChangeRecord;
import com.baijia.tianxiao.sal.signup.dto.request.StudentBalanceRequestDto;
import com.baijia.tianxiao.sal.signup.dto.response.StudentBalanceResponseDto;
import com.baijia.tianxiao.sal.signup.service.TxStudentFinanceAccountService;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.GenericsUtils;
import com.baijia.tianxiao.util.mobile.MaskUtil;
import com.google.common.collect.Lists;

import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class TxStudentFinanceAccountServiceImpl implements TxStudentFinanceAccountService {

    @Resource
    private TxStudentFinanceAccountDao txStudentFinanceAccountDao;

    @Resource
    private TxStudentFinanceRecordDao txStudentFinanceRecordDao;

    @Autowired
    private TXCascadeCredentialDao txCascadeCredentialDao;
    @Autowired
    private OrgInfoDao orgInfoDao;

    @Resource
    private OrgStudentDao orgStudentDao;

    @Resource
    private TxCascadeCredentialService txCascadeCredentialService;

    @Override
    public void changeStudentFiannceAccount(Long orgId, Integer cascadeId, Long studentId, StudentFiannceOpType opType,
                                            Long money, String opInfo, String remark) {
        log.info("ChangeStudentFiannceAccount params={},{},{} {},{},{}", orgId, cascadeId, studentId, opType, money,
                opInfo);

        OrgStudent orgStudent = orgStudentDao.getById(studentId);
        if (orgStudent == null) {
            throw new BussinessException(CommonErrorCode.BUSINESS_ERROR, "学员不存在");
        }
        /**
         * 财务账号
         */
        TxStudentFinanceAccount txStudentFinanceAccount =
                txStudentFinanceAccountDao.getFinanceAccount(orgId, studentId);
        if (txStudentFinanceAccount == null) {
            txStudentFinanceAccount = new TxStudentFinanceAccount();
            txStudentFinanceAccount.setOrgId(orgId);
            txStudentFinanceAccount.setStudentId(studentId);
            txStudentFinanceAccount.setCreateTime(new Date());
        }

        /**
         * 财务变更记录
         */
        TxStudentFinanceRecord txStudentFinanceRecord = new TxStudentFinanceRecord();
        txStudentFinanceRecord.setOrgId(orgId);
        txStudentFinanceRecord.setStudentId(studentId);
        txStudentFinanceRecord.setCreateTime(new Date());
        txStudentFinanceRecord.setUpdateTime(new Date());
        txStudentFinanceRecord.setOpMoney(money);
        txStudentFinanceRecord.setOpType(opType.getCode());
        txStudentFinanceRecord.setCascadeId(cascadeId);
        txStudentFinanceRecord.setRemark(remark);

        if (opType == StudentFiannceOpType.QUIT_CLASS) {
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        } else if (opType == StudentFiannceOpType.RECHARGE) {
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo("学员" + orgStudent.getName() + "充值");
        } else if (opType == StudentFiannceOpType.REFUND_CASH) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getBalance() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常或有冻结金额");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() - money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setOpInfo("学员" + orgStudent.getName() + "从账户退款");
        } else if (opType == StudentFiannceOpType.PAY_SUCCESS) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getFreezeMoney() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() - money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setIsShow(1);
            txStudentFinanceRecord.setOpInfo("系统支付成功");
        } else if (opType == StudentFiannceOpType.PAY_CANCEL) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getFreezeMoney() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() - money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        } else if (opType == StudentFiannceOpType.SIGNUP_PAY) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getBalance() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() - money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() + money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        }

        txStudentFinanceAccount.setUpdateTime(new Date());
        log.info("ChangeStudentFiannceAccount result1={}", txStudentFinanceAccount);
        txStudentFinanceAccountDao.saveOrUpdate(txStudentFinanceAccount);// 账号更新或保存

        log.info("ChangeStudentFiannceAccount result2={}", txStudentFinanceRecord);
        txStudentFinanceRecordDao.save(txStudentFinanceRecord);// 变更记录保存
    }

    /**
     * 查找用户储值账号的操作记录
     */
    @Override
    public List<TxStudentFinanceRecord> findStudentFiannceAccountRecord(Long orgId, Long studentId, PageDto pageDto) {
        return this.txStudentFinanceRecordDao.findTxStudentFinanceRecords(orgId, studentId, pageDto);
    }

    @Override
    public List<TxStudentFinanceAccountDto> findStudentFiannceAccount(Long orgId, Integer cascadeId, String key,
                                                                      PageDto pageDto) {
        pageDto.setCount(txStudentFinanceAccountDao.countByStudentAccount(orgId, key));

        List<TxStudentFinanceAccountDto> list = this.txStudentFinanceAccountDao.searchByStudentAccount(orgId, key, pageDto);
        if (CollectionUtils.isEmpty(list)) {
            return Collections.EMPTY_LIST;
        }

        boolean isShowMobile = txCascadeCredentialService.isShowMobile(orgId, cascadeId);
        for (TxStudentFinanceAccountDto dto : list) {
            if (!isShowMobile) {
                dto.setStudentMobile(MaskUtil.maskMobile(dto.getStudentMobile()));
            } else {
                dto.setStudentMobile(dto.getStudentMobile());
            }
        }
        return list;
    }

    @Override
    public StudentBalanceResponseDto findStudentBalanceResponseDto(StudentBalanceRequestDto request) {
        Long orgId = request.getOrgId();
        Long studentId = request.getStudentId();
        TxStudentFinanceAccount financeAccount = this.txStudentFinanceAccountDao.getFinanceAccount(orgId, studentId);
        log.info("financeAccount is :{} ", financeAccount);
        List<BalanceChangeRecord> records = Lists.newArrayList();
        StudentBalanceResponseDto studentBalanceResponseDto =
                StudentBalanceResponseDto.newInstance(financeAccount, records);
        if (request.isNeedBanlacneChangeRecords()) {
            List<TxStudentFinanceRecord> findStudentFiannceAccountRecord =
                    this.findStudentFiannceAccountRecord(orgId, studentId, request.getPageDto());
            log.info("findStudentFiannceAccountRecord are :{} ", findStudentFiannceAccountRecord);
            records.addAll(createBalanceChangeRecords(findStudentFiannceAccountRecord));
            List<Integer> cascadeIds = GenericsUtils.toFieldList(records, "operatorId");
            Map<Long, String> txCascadCredentialListByCascdeIds =
                    this.txCascadeCredentialDao.getTxCascadCredentialListByCascdeIds(cascadeIds);
            if (cascadeIds.contains(0)) {
                OrgInfo orginfo = orgInfoDao.getOrgInfo(orgId.intValue());
                txCascadCredentialListByCascdeIds.put(0l, orginfo.getContacts());
            }
            for (BalanceChangeRecord bcr : records) {
                Long operatorId = bcr.getOperatorId().longValue();
                String operator = txCascadCredentialListByCascdeIds.get(operatorId);
                if (GenericsUtils.isNullOrEmpty(operator)) {
                    operator = "[系统]";
                }
                bcr.setOperator(operator);
            }
            log.info("records are :{} ", records);
        }
        return studentBalanceResponseDto;
    }

    /**
     * @param findStudentFiannceAccountRecord
     * @return
     */
    private List<BalanceChangeRecord> createBalanceChangeRecords(
            List<TxStudentFinanceRecord> findStudentFiannceAccountRecord) {
        if (GenericsUtils.isNullOrEmpty(findStudentFiannceAccountRecord)) {
            return GenericsUtils.emptyList();
        }
        List<BalanceChangeRecord> retRecords = Lists.newArrayList();
        for (TxStudentFinanceRecord record : findStudentFiannceAccountRecord) {
            BalanceChangeRecord bcr = BalanceChangeRecord.newInstance(record);
            retRecords.add(bcr);
        }
        return retRecords;
    }

}

==> sal-signup-2.20.0-20170424.063550-97-sources.jar: com/baijia/tianxiao/sal/signup/service/Impl/TxStudentFinanceAccountServiceImpl.java <==
package com.baijia.tianxiao.sal.signup.service.Impl;

import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Map;

import javax.annotation.Resource;

import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceAccountDto;
import com.baijia.tianxiao.sal.signup.dto.SignupRefundStorageDto;
import com.baijia.tianxiao.sal.signup.service.SignupRefundStorageService;
import com.baijia.tianxiao.util.StringUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.baijia.tianxiao.constant.StudentFiannceOpType;
import com.baijia.tianxiao.dal.finance.dao.TxStudentFinanceAccountDao;
import com.baijia.tianxiao.dal.finance.dao.TxStudentFinanceRecordDao;
import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceAccount;
import com.baijia.tianxiao.dal.finance.po.TxStudentFinanceRecord;
import com.baijia.tianxiao.dal.org.dao.OrgInfoDao;
import com.baijia.tianxiao.dal.org.dao.OrgStudentDao;
import com.baijia.tianxiao.dal.org.dao.TXCascadeCredentialDao;
import com.baijia.tianxiao.dal.org.po.OrgInfo;
import com.baijia.tianxiao.dal.org.po.OrgStudent;
import com.baijia.tianxiao.enums.CommonErrorCode;
import com.baijia.tianxiao.exception.BussinessException;
import com.baijia.tianxiao.sal.organization.finance.constant.FinanceOpTo;
import com.baijia.tianxiao.sal.organization.org.service.TxCascadeCredentialService;
import com.baijia.tianxiao.sal.signup.dto.BalanceChangeRecord;
import com.baijia.tianxiao.sal.signup.dto.request.StudentBalanceRequestDto;
import com.baijia.tianxiao.sal.signup.dto.response.StudentBalanceResponseDto;
import com.baijia.tianxiao.sal.signup.service.TxStudentFinanceAccountService;
import com.baijia.tianxiao.sqlbuilder.dto.PageDto;
import com.baijia.tianxiao.util.GenericsUtils;
import com.baijia.tianxiao.util.mobile.MaskUtil;
import com.google.common.collect.Lists;

import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class TxStudentFinanceAccountServiceImpl implements TxStudentFinanceAccountService {

    @Resource
    private TxStudentFinanceAccountDao txStudentFinanceAccountDao;

    @Resource
    private TxStudentFinanceRecordDao txStudentFinanceRecordDao;

    @Autowired
    private TXCascadeCredentialDao txCascadeCredentialDao;
    @Autowired
    private OrgInfoDao orgInfoDao;

    @Resource
    private OrgStudentDao orgStudentDao;

    @Resource
    private TxCascadeCredentialService txCascadeCredentialService;

    @Resource
    private SignupRefundStorageService signupRefundStorageService;

    @Override
    public void changeStudentFiannceAccount(Long orgId, Integer cascadeId, Long studentId, StudentFiannceOpType opType,
                                            Long money, String opInfo, String remark) {
        log.info("ChangeStudentFiannceAccount params={},{},{} {},{},{}", orgId, cascadeId, studentId, opType, money,
                opInfo);

        OrgStudent orgStudent = orgStudentDao.getById(studentId);
        if (orgStudent == null) {
            throw new BussinessException(CommonErrorCode.BUSINESS_ERROR, "学员不存在");
        }
        /**
         * 财务账号
         */
        TxStudentFinanceAccount txStudentFinanceAccount =
                txStudentFinanceAccountDao.getFinanceAccount(orgId, studentId);
        if (txStudentFinanceAccount == null) {
            txStudentFinanceAccount = new TxStudentFinanceAccount();
            txStudentFinanceAccount.setOrgId(orgId);
            txStudentFinanceAccount.setStudentId(studentId);
            txStudentFinanceAccount.setCreateTime(new Date());
        }

        /**
         * 财务变更记录
         */
        TxStudentFinanceRecord txStudentFinanceRecord = new TxStudentFinanceRecord();
        txStudentFinanceRecord.setOrgId(orgId);
        txStudentFinanceRecord.setStudentId(studentId);
        txStudentFinanceRecord.setCreateTime(new Date());
        txStudentFinanceRecord.setUpdateTime(new Date());
        txStudentFinanceRecord.setOpMoney(money);
        txStudentFinanceRecord.setOpType(opType.getCode());
        txStudentFinanceRecord.setCascadeId(cascadeId);
        txStudentFinanceRecord.setRemark(remark);

        if (opType == StudentFiannceOpType.QUIT_CLASS) {
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        } else if (opType == StudentFiannceOpType.RECHARGE) {
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo("学员" + orgStudent.getName() + "充值");
        } else if (opType == StudentFiannceOpType.REFUND_CASH) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getBalance() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常或有冻结金额");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() - money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());

            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setOpInfo("学员" + orgStudent.getName() + "从账户退款");
        } else if (opType == StudentFiannceOpType.PAY_SUCCESS) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getFreezeMoney() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() - money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setIsShow(1);
            txStudentFinanceRecord.setOpInfo("系统支付成功");
        } else if (opType == StudentFiannceOpType.PAY_CANCEL) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getFreezeMoney() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() + money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() - money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.INCOME.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        } else if (opType == StudentFiannceOpType.SIGNUP_PAY) {
            if (txStudentFinanceAccount.getId() == null || txStudentFinanceAccount.getBalance() < money) {
                throw new BussinessException(CommonErrorCode.SIGN_INVALIDATE, "学生账号变动金额异常");
            }
            txStudentFinanceRecord.setPreBalance(txStudentFinanceAccount.getBalance());
            txStudentFinanceAccount.setBalance(txStudentFinanceAccount.getBalance() - money);
            txStudentFinanceRecord.setCurrBalance(txStudentFinanceAccount.getBalance());

            txStudentFinanceRecord.setPreFreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceAccount.setFreezeMoney(txStudentFinanceAccount.getFreezeMoney() + money);
            txStudentFinanceRecord.setCurrfreezeMoney(txStudentFinanceAccount.getFreezeMoney());
            txStudentFinanceRecord.setOpTo(FinanceOpTo.EXPEND.getCode());
            txStudentFinanceRecord.setOpInfo(opInfo);
        }

        txStudentFinanceAccount.setUpdateTime(new Date());
        log.info("ChangeStudentFiannceAccount result1={}", txStudentFinanceAccount);
        txStudentFinanceAccountDao.saveOrUpdate(txStudentFinanceAccount);// 账号更新或保存

        log.info("ChangeStudentFiannceAccount result2={}", txStudentFinanceRecord);
        txStudentFinanceRecordDao.save(txStudentFinanceRecord);// 变更记录保存
    }

    /**
     * 查找用户储值账号的操作记录
     */
    @Override
    public List<TxStudentFinanceRecord> findStudentFiannceAccountRecord(Long orgId, Long studentId, PageDto pageDto) {
        return this.txStudentFinanceRecordDao.findTxStudentFinanceRecords(orgId, studentId, pageDto);
    }

    @Override
    public List<TxStudentFinanceAccountDto> findStudentFiannceAccount(Long orgId, Integer cascadeId, String key,
                                                                      PageDto pageDto) {
        pageDto.setCount(txStudentFinanceAccountDao.countByStudentAccount(orgId, key));

        List<TxStudentFinanceAccountDto> list = this.txStudentFinanceAccountDao.searchByStudentAccount(orgId, key, pageDto);
        if (CollectionUtils.isEmpty(list)) {
            return Collections.EMPTY_LIST;
        }

        boolean isShowMobile = txCascadeCredentialService.isShowMobile(orgId, cascadeId);
        for (TxStudentFinanceAccountDto dto : list) {
            if (!isShowMobile) {
                dto.setStudentMobile(MaskUtil.maskMobile(dto.getStudentMobile()));
            } else {
                dto.setStudentMobile(dto.getStudentMobile());
            }
        }
        return list;
    }

    @Override
    public StudentBalanceResponseDto findStudentBalanceResponseDto(StudentBalanceRequestDto request) {
        Long orgId = request.getOrgId();
        Long studentId = request.getStudentId();
        TxStudentFinanceAccount financeAccount = this.txStudentFinanceAccountDao.getFinanceAccount(orgId, studentId);
        log.info("financeAccount is :{} ", financeAccount);
        List<BalanceChangeRecord> records = Lists.newArrayList();
        StudentBalanceResponseDto studentBalanceResponseDto =
                StudentBalanceResponseDto.newInstance(financeAccount, records);
        if (request.isNeedBanlacneChangeRecords()) {
            List<TxStudentFinanceRecord> findStudentFiannceAccountRecord =
                    this.findStudentFiannceAccountRecord(orgId, studentId, request.getPageDto());
            log.info("findStudentFiannceAccountRecord are :{} ", findStudentFiannceAccountRecord);
            records.addAll(createBalanceChangeRecords(findStudentFiannceAccountRecord));
            List<Integer> cascadeIds = GenericsUtils.toFieldList(records, "operatorId");
            Map<Long, String> txCascadCredentialListByCascdeIds =
                    this.txCascadeCredentialDao.getTxCascadCredentialListByCascdeIds(cascadeIds);
            if (cascadeIds.contains(0)) {
                OrgInfo orginfo = orgInfoDao.getOrgInfo(orgId.intValue());
                txCascadCredentialListByCascdeIds.put(0l, orginfo.getContacts());
            }
            for (BalanceChangeRecord bcr : records) {
                Long operatorId = bcr.getOperatorId().longValue();
                String operator = txCascadCredentialListByCascdeIds.get(operatorId);
                if (GenericsUtils.isNullOrEmpty(operator)) {
                    operator = "[系统]";
                }
                bcr.setOperator(operator);
                if (bcr.getOpType().intValue() == StudentFiannceOpType.QUIT_CLASS.getCode()) {
                    if (!StringUtils.isEmpty(bcr.getComment())) {
                        changeQuitClassRemark(bcr, orgId);
                    }
                }
            }
            log.info("records are :{} ", records);
        }
        return studentBalanceResponseDto;
    }


    private void changeQuitClassRemark(BalanceChangeRecord recordDto, Long orgId) {
        try {
            String[] params = recordDto.getComment().split("_");
            List<SignupRefundStorageDto> result = signupRefundStorageService.getSignupRefundStorages(orgId,
                    Long.parseLong(params[0]), Long.parseLong(params[2]), Long.parseLong(params[1]));
            recordDto.setRemarkImages(result);
            if (!result.isEmpty()) {
                recordDto.setComment(result.get(0).getRemark());
                if (result.get(0).getStorageId().longValue() == 0) {
                    recordDto.setRemarkImages(Lists.<SignupRefundStorageDto>newArrayList());
                }
            } else {
                recordDto.setComment("");
            }
        } catch (Exception e) {
            recordDto.setComment("");
        }
    }

    /**
     * @param findStudentFiannceAccountRecord
     * @return
     */
    private List<BalanceChangeRecord> createBalanceChangeRecords(
            List<TxStudentFinanceRecord> findStudentFiannceAccountRecord) {
        if (GenericsUtils.isNullOrEmpty(findStudentFiannceAccountRecord)) {
            return GenericsUtils.emptyList();
        }
        List<BalanceChangeRecord> retRecords = Lists.newArrayList();
        for (TxStudentFinanceRecord record : findStudentFiannceAccountRecord) {
            BalanceChangeRecord bcr = BalanceChangeRecord.newInstance(record);
            retRecords.add(bcr);
        }
        return retRecords;
    }

}
